@@ -19,7 +19,7 @@ import warnings
 from ctypes.util import find_library
 from abc import ABC, abstractmethod
 
-__version__ = "2.0.0"
+__version__ = "2.1.0"
 __all__ = ["threadpool_limits", "threadpool_info"]
 
 
@@ -757,3 +757,40 @@ class _OpenMPModule(_Module):
 
     def _get_extra_info(self):
         pass
+
+
+def _main():
+    """Commandline interface to display thread-pool information and exit."""
+    import argparse
+    import importlib
+    import json
+    import sys
+
+    parser = argparse.ArgumentParser(
+        usage="python -m threadpoolctl -i numpy scipy.linalg xgboost",
+        description="Display thread-pool information and exit.",
+    )
+    parser.add_argument(
+        "-i", "--import", dest="modules", nargs="*", default=(),
+        help="Python modules to import before introspecting thread-pools."
+    )
+    parser.add_argument(
+        "-c", "--command",
+        help="a Python statement to execute before introspecting"
+             " thread-pools.")
+
+    options = parser.parse_args(sys.argv[1:])
+    for module in options.modules:
+        try:
+            importlib.import_module(module, package=None)
+        except ImportError:
+            print("WARNING: could not import", module, file=sys.stderr)
+
+    if options.command:
+        exec(options.command)
+
+    print(json.dumps(threadpool_info(), indent=2))
+
+
+if __name__ == "__main__":
+    _main()
